StaticExactCap

Struct StaticExactCap 

pub struct StaticExactCap<const SIZE: usize>;
A marker for a static exact size constraint, where MIN == MAX.

Type Parameters

  • SIZE: The size of both the inclusive minimum and maximum capacity constraints.

Implementations

Source

impl<const SIZE: usize> StaticExactCap<SIZE>

pub const RANGE: RangeInclusive<usize>

The equivalent range.