pub struct StaticExactCap<const SIZE: usize>;Expand description
A marker for a static exact size constraint, where MIN == MAX.
Type Parameters
SIZE: The size of both the inclusive minimum and maximum capacity constraints.
Implementations
Sourceimpl<const SIZE: usize> StaticExactCap<SIZE>
impl<const SIZE: usize> StaticExactCap<SIZE>
Sourcepub const RANGE: RangeInclusive<usize>
pub const RANGE: RangeInclusive<usize>
The equivalent range.